Package: readabs
Type: Package
Title: Download and Tidy Time Series Data from the Australian Bureau of
        Statistics
Version: 0.4.30
Authors@R: c(
           person("Matt", "Cowgill", role = c("aut", "cre"), email = "mattcowgill@gmail.com", comment = c(ORCID = "0000-0003-0422-3300")),
           person("Zoe", "Meers", role = "aut", email = "zoe.meers@sydney.edu.au"),
           person("Jaron", "Lee", role = "aut", email = "jaron.lee@sydney.edu.au"),
           person("David", "Diviny", role = "aut", email = "David.Diviny@nousgroup.com.au"),
           person("Hugh", "Parsonage", role = "ctb", email = "hugh.parsonage@gmail.com"),
           person("Kinto", "Behr", role = "ctb", email = "kinto.behr@gmail.com"),
           person("Angus", "Moore", role = "ctb"),
           person("Francis", "Markham", role = "ctb", comment = c(ORCID = "0000-0002-4266-2569"))
           )
Maintainer: Matt Cowgill <mattcowgill@gmail.com>
Description: Downloads, imports, and tidies time series data from the 
    Australian Bureau of Statistics <https://www.abs.gov.au/>.
License: MIT + file LICENSE
Encoding: UTF-8
Depends: R (>= 3.5)
Imports: readxl (>= 1.2.0), dplyr (>= 0.8.0), hutils (>= 1.5.0), fst,
        purrr (>= 1.0.0), tidyr (>= 1.0.0), stringi, tools, glue, httr,
        rvest, xml2, rlang, labelled
URL: https://github.com/mattcowgill/readabs
BugReports: https://github.com/mattcowgill/readabs/issues
VignetteBuilder: knitr
Suggests: knitr, rmarkdown, markdown, testthat (>= 2.1.0), ggplot2
Config/roxygen2/version: 8.0.0
NeedsCompilation: no
Packaged: 2026-05-17 09:59:27 UTC; mcowgill
Author: Matt Cowgill [aut, cre] (ORCID:
    <https://orcid.org/0000-0003-0422-3300>),
  Zoe Meers [aut],
  Jaron Lee [aut],
  David Diviny [aut],
  Hugh Parsonage [ctb],
  Kinto Behr [ctb],
  Angus Moore [ctb],
  Francis Markham [ctb] (ORCID: <https://orcid.org/0000-0002-4266-2569>)
Repository: CRAN
Date/Publication: 2026-05-17 13:10:02 UTC
Built: R 4.5.2; ; 2026-05-17 13:58:08 UTC; unix
