% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/read_cpi.R
\name{read_cpi}
\alias{read_cpi}
\title{Download a tidy tibble containing the Consumer Price Index from the ABS}
\usage{
read_cpi(
  frequency = c("quarterly", "monthly"),
  path = Sys.getenv("R_READABS_PATH", unset = tempdir()),
  ...
)
}
\arguments{
\item{frequency}{Either \code{"quarterly"} (the default) or \code{"monthly"}.}

\item{path}{character; default is "data/ABS". Only used if
retain_files is set to TRUE. Local directory in which to save
downloaded ABS time series spreadsheets.}

\item{...}{Arguments passed to \code{read_abs()}. See \code{?read_abs} for details.}
}
\description{
\code{read_cpi()} uses the \code{read_abs()} function to download, import,
and tidy the quarterly Consumer Price Index from the ABS. It returns a tibble
containing two columns: the date and the CPI index value that corresponds
to that date. This makes joining the CPI to another dataframe easy.
\code{read_cpi()} returns the original (ie. not seasonally adjusted)
all groups CPI for Australia. If you want the analytical series
(eg. seasonally adjusted CPI, or trimmed mean CPI) or monthly series, you can use
\code{read_abs()}.
}
\details{
By default, \code{read_abs()} retrieves the quarterly CPI. It can use the
\code{frequency} argument to change to monthly.
}
\examples{

# Create a tibble called 'cpi' that contains the CPI index
# numbers for each quarter
\donttest{
cpi <- read_cpi()
}

# This tibble can now be joined to another to help streamline the process of
# deflating nominal values.
}
